@@ -55,12 +55,13 @@ class VPC():
             return err
 
 
-    def allocateAddresses(self, AddressType='EIP', AddressCount=1):
+    def allocateAddresses(self, AddressType='EIP', AddressCount=1, AddressName=''):
         """[创建弹性公网IP]https://cloud.tencent.com/document/api/215/16699
 
         Args:
             AddressType (str, optional): [EIP类型：'EIP'、'AnycastEIP'：加速IP、'HighQualityEIP'：精品IP]. 默认值：EIP.
             AddressCount (int, optional): [EIP数量]. 默认值：1.
+            AddressName (str, optional): [EIP名称].
         
         Returns:
             [json]: [json response]
@@ -71,7 +72,8 @@ class VPC():
                 "AddressCount": AddressCount,
                 "InternetChargeType": self.InternetChargeType,
                 "InternetMaxBandwidthOut": self.InternetMaxBandwidthOut,
-                "AddressType": AddressType
+                "AddressType": AddressType,
+                "AddressName": AddressName,
             }
             req.from_json_string(json.dumps(params))
 
@@ -189,7 +191,7 @@ class VPC():
 
 
 
-    def describeAddresses(self, address_id='', address_ip='', address_status='', instance_id='', network_interface_id=''):
+    def describeAddresses(self, address_id='', address_ip='', address_status='', instance_id='', network_interface_id='', address_name=''):
         """[查询弹性公网IP列表]https://cloud.tencent.com/document/api/215/16702
 
         有且只能选择以下一个条件进行过滤查询。
@@ -199,6 +201,7 @@ class VPC():
             address_status (str, optional): [按照 EIP 的状态过滤，状态包含：'CREATING'，'BINDING'，'BIND'，'UNBINDING'，'UNBIND'，'OFFLINING'，'BIND_ENI'。]. Defaults to ''.
             instance_id (str, optional): [按照 EIP 绑定的实例 ID 过滤]. Defaults to ''.
             network_interface_id (str, optional): [按照 EIP 绑定的弹性网卡 ID 过滤]. Defaults to ''.
+            address_name (str, optional): [按照 EIP 名称过滤。不支持模糊过滤。]. Defaults to ''.
 
         Returns:
             [json]: [json response]
@@ -216,6 +219,8 @@ class VPC():
                 params = {"Filters": [{"Name": "instance-id","Values": [ instance_id ]}]}
             elif len(network_interface_id) > 0:
                 params = {"Filters": [{"Name": "network-interface-id","Values": [ network_interface_id ]}]}
+            elif len(address_name) > 0:
+                params = {"Filters": [{"Name": "address-name","Values": [ address_name ]}]}
 
             req.from_json_string(json.dumps(params))
 
@@ -229,11 +234,11 @@ class VPC():
 
 
 
-    def createNetworkInterface(self, NetworkInterfaceName='eth1'):
+    def createNetworkInterface(self, NetworkInterfaceName=''):
         """[创建弹性网卡]https://cloud.tencent.com/document/api/215/15818
 
         Args:
-            NetworkInterfaceName (str, optional): [弹性网卡名称]. 默认值：'eth1'.
+            NetworkInterfaceName (str, optional): [弹性网卡名称].
 
         Returns:
             [json]: [json response]
